NAME

Map::Tube::CLI - Command Line Interface for Map::Tube::* map.

VERSION

Version v1.1.0

DESCRIPTION

This module provides a simple command line interface to the package consuming Map::Tube. The distribution also contains a script map-tube for use at the command line which uses this package.

SYNOPSIS

You can list all command line options by giving the -h flag.

$ map-tube -h
USAGE: map-tube [-h] [options...]

    -m --map=String      Map name
    -s --start=String    Start station name
    -e --end=String      End station name
    -p --preferred       Show preferred route
    -g --generate_map    Generate map as image
    -i --image=String    Name of image file or format (optional; default
                         format: PNG)
    --layout=String      Layout strategy for image (default: dot)
    -b --bgcolor=String  Map background color
    -l --line=String     Line name to map
    --line_mappings      Generate line mappings as table
    --line_notes         Generate line notes
    -M --list_maps       List supported maps
    -L --list_lines      List lines in given map
    -S --list_stations   List stations in given map
    -F --fuzzy           Fuzzy station name matching (on by default if
                         needed; switch off with --no-fuzzy)
    -P --penalty=Real    Change hop count penalty for line changes (default: 0.5)
    -t --tabular         Show routes and notes in tabular format
    -f --force           Force unsupported map (map name becomes case sensitive)
    -D --debug           Run in debug mode
    -V --version         Show version information

    --usage              show a short help message
    -h                   show a compact help message
    --help               show a long help message
    --man                show the manual

COMMON USAGES

Finding the Shortest Route

Shortest Route

You can ask for the shortest route in the London Tube Map as below: (Under Windows use double quotes.)

$ map-tube --map London --start 'Baker Street' --end 'Wembley Park'

Baker Street (Bakerloo, Circle, Hammersmith & City, Jubilee, Metropolitan), Finchley Road (Jubilee, Metropolitan), Wembley Park (Jubilee, Metropolitan)

If any of the station names does not exist literally (up to capitalisation), fuzzy matching will be attempted. If this yields unique stations, they will be used. Otherwise, the candidate stations are displayed and no route will be calculated. You can always force fuzzy matching by adding the "--fuzzy" command line argument.

Preferred Shortest Route

Now a request for the preferred route:

$ map-tube --map London --start 'Baker Street' --end 'Euston Square' --preferred

Baker Street (Circle, Hammersmith & City, Metropolitan), Great Portland Street (Circle, Hammersmith & City, Metropolitan), Euston Square (Circle, Hammersmith & City, Metropolitan)

Preferred Shortest Route in Tabular Form

And a request for the preferred route displayed as a table: (This also shows the use of short options.)

$ map-tube -m London -s 'Baker Street' -e 'Euston Square' -p -t
Metro Map London: Route from Baker Street to Euston Square.

.--------------------------------------------------------------------.
| Station Name          | Lines                                      |
+-----------------------+--------------------------------------------+
| Baker Street          | Circle, Hammersmith and City, Metropolitan |
| Great Portland Street | Circle, Hammersmith and City, Metropolitan |
| Euston Square         | Circle, Hammersmith and City, Metropolitan |
'-----------------------+--------------------------------------------'

Baker Street (Circle, Hammersmith & City, Metropolitan), Great Portland Street (Circle, Hammersmith & City, Metropolitan), Euston Square (Circle, Hammersmith & City, Metropolitan)

Handling of Tube Line Changes

Counting the number of hops is one valid way to measure the distance between two stations. Practically speaking, however, having to change lines will add to the perceived distance. To account for this, Map::Tube puts a penalty of one half hop on each line change required, i.e., routes with fewer line changes are slightly more welcome. You can either switch off this behaviour by

$ map-tube -m London -s 'Baker Street' -e 'Euston Square' --penalty 0

or put an even heavier penalty on line changes:

$ map-tube -m London -s 'Baker Street' -e 'Euston Square' --penalty 2

(In this particular case, the output will be identical because there are no line changes involved.)

Station Names

Ideally you will know the exact names of the stations, like in the examples above. If you don't, you can always get a full list of station names with the --list-stations argument (cf. below). But Map::Tube tries to help you if it cannot find the exact station name (case never matters anyway). In this case, it will try to find a similar name. (What exactly is meant by "similar" is a bit involved; never mind.) If it finds a unique candidate, it will use that and notify you that it did some guessing:

$ map-tube -m London -s Baker -e 'Euston Square'
Metro Map London: Route from Baker Street (guessed) to Euston Square.

.--------------------------------------------------------------------.
| Station Name          | Lines                                      |
+-----------------------+--------------------------------------------+
| Baker Street          | Circle, Hammersmith and City, Metropolitan |
| Great Portland Street | Circle, Hammersmith and City, Metropolitan |
| Euston Square         | Circle, Hammersmith and City, Metropolitan |
'-----------------------+--------------------------------------------'

If no clear best guess can be found, you will be offered with some possibilities:

$ map-tube -m London -s "Back Street" -e 'Euston Square'
Map::Tube::CLI::run(): ERROR: Invalid Station Name [Back Street]; maybe one of Baker Street
(Bakerloo, Circle, Hammersmith and City, Jubilee, Metropolitan), Becontree (District),
Bond Street (Central, Elizabeth, Jubilee), Old Street (Northern), Wood Street (Weaver)?
(status: 101) file C:/Strawberry/perl/site/lib/Map/Tube/CLI.pm on line 454

You can also use regular expressions:

$ map-tube -m London -s "Bak.*St.*" -e 'Euston Square'
Metro Map London: Route from Baker Street (guessed) to Euston Square.

.--------------------------------------------------------------------.
| Station Name          | Lines                                      |
+-----------------------+--------------------------------------------+
| Baker Street          | Circle, Hammersmith and City, Metropolitan |
| Great Portland Street | Circle, Hammersmith and City, Metropolitan |
| Euston Square         | Circle, Hammersmith and City, Metropolitan |
'-----------------------+--------------------------------------------'

If you can always force fuzzy matching with the argument --fuzzy, or you can completely disable it with --no-fuzzy.

Images of Maps

Generate an Image of the Full Map

To generate a graphical representation of the entire map, follow the command below. This will generate a PNG file named after the map in your current working directory. (It will silently overwrite any pre-existing file of the same name.)

$ map-tube --map Delhi --generate_map

In case you want a different background color to the map then you can try this:

$ map-tube --map Delhi --bgcolor gray --generate_map

The output file name is chosen automatically according to the map. It will be displayed on the console. If you want a different file name, do this:

$ map-tube --map Delhi --generate_map --image Delhicious.png

This allows you also to pick other output formats than PNG. E.g., you might want a vector graphics file:

$ map-tube --map Delhi --generate_map --image Delhivector.svg

Or if you are happy with the default file name but still want to have a non-standard format:

$ map-tube --map Delhi --generate_map --image pdf

Which output formats you can choose depends on your particular GraphViz installation, so check the GraphViz documentation.

There is a number of different approaches to the layout of such diagrams, and GraphViz offers several (again, consult the GraphvIz documentation). The default is dot, but often neato or sfdp also offer good representations. Which one is "best" is a matter of taste and also depends on the map at hand. Try this:

$ map-tube --map Delhi --generate_map --layout neato

Generate Just a Line Map

To generate a graphical representation of just a particular line, follow the command below. This will generate a PNG file named after the line in your current working directory. (It will silently overwrite any pre-existing file of the same name.)

$ map-tube --map London --line Bakerloo --generate_map

In case you want a different background color to the map then you can try this:

$ map-tube --map London --line DLR --bgcolor yellow --generate_map

Additional Information on Lines, Stations, and Maps

Generate Line Mappings as a Table

This will show all stops on the given lane, as far as possible in the correct order:

$ map-tube --map London --line Bakerloo --line_mappings

All that has been said above about output file names, image formats and layout algorithms applies also to line maps.

Generate Line Notes

This will show which other lines are serving the stations on the given line. Stations are ordered alphabetically. Only stations that are served by at least one additional line are shown.

$ map-tube --map London --line Bakerloo --line_notes

It can also be displayed in tabular form:

$ map-tube --map London --line Bakerloo --line_notes --tabular

List the Lines for the Given Map

$ map-tube --map London --list_lines

List the Stations for the Given Map

$ map-tube --map London --list_stations

List all Supported Maps

This will show you a list of all officially supported maps. It will also show you which of these maps are not currently installed on your machine.

$ map-tube --list_maps

Using a Map that is Not Officially Supported

It is also possible to use tube maps that are not officially supported, e.g., privately created maps: (This is also helpful while developing a new map.)

$ map-tube --map 'Slippery Rock' --start 'College Park' --end 'Greyhound station' --force

Error Handling

If encountering an invalid map or a missing map (i.e not installed), you get an error message like below:

$ map-tube --map xYz --start 'Baker Street' --end 'Euston Square'
ERROR: Unsupported Map [xYz].

The following will produce a similar message if you do not have the tube map of Kazan installed; if you do have it, it will notify you that the starting station does not exist in this map:

$ map-tube --map Kazan --start 'Baker Street' --end 'Euston Square'
ERROR: Missing Map [Kazan].

SUPPORTED MAPS

The command line parameter map can take one of the following map names. It is case insensitive, i.e. 'London' and 'lOndOn' are the same. Use the --list_maps option described above to get an up-to-date version of this list. Use the --force option described above to use locally installed maps that are not on that list.

Note that not all officially supported maps might be available at your site. The --list-maps option will show which aren't. You can either install any missing map from CPAN, or you could use Task::Map::Tube::Bundle to install the supported maps. Please make sure you have the latest maps when you install.

METHODS

run()

This is the main method provided by the package Map::Tube::CLI. It does not expect any parameter. Here is the code from the supplied map-tube script.

use strict; use warnings;
use Map::Tube::CLI;

Map::Tube::CLI->new_with_options->run;

supported_maps()

This method will produce information on the maps that are generally recognized by the package Map::Tube::CLI. It does not expect any parameter. It will return a reference to a hash whose keys are plain text city names (in ALL-CAPS) and whose values are the names of the modules that implement the maps.

Note that "generally recognized" does not imply that the city/module in question is actually available on your machine.

AUTHOR

Mohammad Sajid Anwar, <mohammad.anwar at yahoo.com>

CONTRIBUTORS

Gisbert W. Selke, <gws at cpan.org>

REPOSITORY

https://github.com/manwar/Map-Tube-CLI

BUGS

Please report any bugs or feature requests through the web interface at https://github.com/manwar/Map-Tube-CLI/issues. I will be notified and then you'll automatically be notified of progress on your bug as I make changes.

SUPPORT

You can find documentation for this module with the perldoc command.

perldoc Map::Tube::CLI

You can also look for information at:

LICENSE AND COPYRIGHT

Copyright (C) 2015 - 2026 Mohammad Sajid Anwar.

This program is free software; you can redistribute it and / or modify it under the terms of the the Artistic License (2.0). You may obtain a copy of the full license at:

http://www.perlfoundation.org/artistic_license_2_0

Any use, modification, and distribution of the Standard or Modified Versions is governed by this Artistic License.By using, modifying or distributing the Package, you accept this license. Do not use, modify, or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made by someone other than you,you are nevertheless required to ensure that your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge patent license to make, have made, use, offer to sell, sell, import and otherwise transfer the Package with respect to any patent claims licensable by the Copyright Holder that are necessarily infringed by the Package. If you institute patent litigation (including a cross-claim or counterclaim) against any party alleging that the Package constitutes direct or contributory patent infringement,then this Artistic License to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.